searchNodes=[{"doc":"Parse PostgreSQL connection URIs of the form:postgresql://[user[:password]@][netloc][:port][,...][/dbname][?param1=value1&amp;...]and returns a keyword list ready for use with Postgrex.start_link/1.The URI format largely follows the description at https://www.postgresql.org/docs/13/libpq-connect.html#id-1.7.3.8.3.6, with parameter keywords as listed at https://www.postgresql.org/docs/13/libpq-connect.html#LIBPQ-PARAMKEYWORDS .There is only partial correspondence between the PostgreSQL parameters and the Postgrex options. No validation is performed and unrecognized/unsupported URL parameter keywords are passed verbatim. This means that you may be able to stuff simple string parameters into the URL to pass them on to Postgrex, but URIs crafted this way may not be compatible with libpq.In particular, the following PostgreSQL URL phenomena are unhandled/untranslated:Parameter keywords marked as deprectated in the PostgreSQL documentation.Things related to the TCP connection beyond connect_timeout (read timeouts, keepalives, ...).Failover (specifying multiple hosts).Advanced SSL configuration (beyond simply turning it on or off)Related project: https://github.com/s-m-i-t-a/database_url — gives you an Ecto adapter rather than a keyword list.See the documentation of parse/1, the only exposed function, for more details and some examples.","ref":"PostgresqlUri.html","title":"PostgresqlUri","type":"module"},{"doc":"Parse a PostgreSQL URI into a keyword list.ExamplesThese examples should (with suitably chosen values) also work as an argument to the psql command-line client and make it attempt to do the same thing as Postgrex would.Quotidian caseiex&gt; PostgresqlUri.parse(&quot;postgresql://someuser:somepassword@some.ser.ver:2345/somedb&quot;) [ hostname: &quot;some.ser.ver&quot;, database: &quot;somedb&quot;, port: 2345, username: &quot;someuser&quot;, password: &quot;somepassword&quot;, ]No-frills SSLFor the sslmode keyword, any value but &quot;disable&quot; will result in enabling SSL.iex&gt; PostgresqlUri.parse(&quot;postgresql://someuser:somepassword@some.ser.ver/somedb?sslmode=yesplease&quot;) [ hostname: &quot;some.ser.ver&quot;, database: &quot;somedb&quot;, username: &quot;someuser&quot;, password: &quot;somepassword&quot;, ssl: true ]Unix socketPostgreSQL has the concept of a &quot;socket directory&quot; which can hold different Unix sockets, named after port numbers. So, in order to specify a socket belonging to a server listening on a port different from the default (5432), you need to pass in a port number, even though you won't be connecting over TCP.iex&gt; PostgresqlUri.parse(&quot;postgresql:///somedb?user=someuser&amp;password=somepassword&amp;host=/path/to/socketdir&amp;port=2345&quot;) [ database: &quot;somedb&quot;, socket_dir: &quot;/path/to/socketdir&quot;, password: &quot;somepassword&quot;, port: 2345, username: &quot;someuser&quot;, ]Minimal case - local Unix socket, peer authentication.Theoretically, postgresql:///somedb should work. However, Postgrex.start_link/1 works differently from psql here. psql, absent host specification, will try to use a Unix socket, perusing the libpq compile-time default socket directory. Yet Postgrex will fail for this URI (demanding a password), as it doesn't know what socket directory to use. So, to make things work for Postgrex, we will have to pass the socket directory explicitly. The resulting URI still works as intended for psql.iex&gt; PostgresqlUri.parse(&quot;postgresql:///some_db?host=/run/postgresql&quot;) [ database: &quot;some_db&quot;, socket_dir: &quot;/run/postgresql&quot;, ]","ref":"PostgresqlUri.html#parse/1","title":"PostgresqlUri.parse/1","type":"function"},{"doc":"PostgresqlUriSimple Elixir module to parse PostgreSQL connection URIs of the form:postgresql://[user[:password]@][netloc][:port][,...][/dbname][?param1=value1&amp;...]returning a keyword list ready for use with Postgrex.start_link/1, making connecting to a database as simple as:Postgrex.start_link( PostgresqlUri.parse( &quot;postgresql://user:pass@host/somedatabase&quot; ) )For more information and examples, refer to the module documentation on hexdocs.pm.The URI format largely follows the PostgreSQL URI description, with parameter keyword interpretation mostly following the PostgreSQL libpq parameter keywords listing.Using this module to handle a single connection URI variable instead of separate host, port, username, databasename, password, ... variables makes runtime configuration a quite a bit tidier, especially if one needs to read these in (with runtime.exs) from separately set environment variables, in turn separately set in a systemd environment file, in turn templated out through some configuration management system. As a bonus, for quotidian configurations, these URIs can be used verbatim with psql to quickly test a DB connection.","ref":"readme.html","title":"PostgresqlUri","type":"extras"},{"doc":"While it is unlikely that for mundane parameters interpretation will radically change from version to version, be aware that non-point releases might change parsing outcomes from version to version. Hard-pin this package if it currently parses your URIs to satisfaction, and sleep better for it.","ref":"readme.html#versioning","title":"PostgresqlUri - Versioning","type":"extras"},{"doc":"The package can be installed by adding postgresql_uri to your list of dependencies in mix.exs:def deps do [ {:postgresql_uri, &quot;~&gt; 0.1.0&quot;} ] end","ref":"readme.html#installation","title":"PostgresqlUri - Installation","type":"extras"}]